==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/booleancolumn.js <==
joo.classLoader.prepare("package ext.config",/* {*/


/**
 * A Column definition class which renders boolean data fields. See the <a href="output/Ext.grid.Column.html#Ext.grid.Column-xtype">xtype</a> config option of <a href="Ext.grid.Column.html">Ext.grid.Column</a> for more details.

 *
 * <p>This class represents the xtype 'booleancolumn' and serves as a
 * typed config object for constructor of class BooleanColumn.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.BooleanColumn
 */
{ExtConfig:{target:"ext.grid.BooleanColumn", gctype:"booleancolumn"}},
"public class booleancolumn extends ext.config.gridcolumn",3,function($$private){;return[ 

  "public function booleancolumn",function booleancolumn$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    ext.config.gridcolumn.call(this,config);
  },


  /**
   The string returned by the renderer when the column value is falsy (but not undefined) (defaults to <tt>'false'</tt>).
   */
  "public native function get falseText"/*():String*/,

  /**
   * @private
   */
  "public native function set falseText"/*(value:String):void*/,

  /**
   The string returned by the renderer when the column value is not falsy (defaults to <tt>'true'</tt>).
   */
  "public native function get trueText"/*():String*/,

  /**
   * @private
   */
  "public native function set trueText"/*(value:String):void*/,

  /**
   The string returned by the renderer when the column value is undefined (defaults to <tt>'&amp;#160;'</tt>).
   */
  "public native function get undefinedText"/*():String*/,

  /**
   * @private
   */
  "public native function set undefinedText"/*(value:String):void*/,


];},[],["ext.config.gridcolumn"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/booleancolumn.js <==
joo.classLoader.prepare("package ext.config",/* {*/


/**
 * A Column definition class which renders boolean data fields. See the <a href="output/Ext.grid.Column.html#Ext.grid.Column-xtype">xtype</a> config option of <a href="Ext.grid.Column.html">Ext.grid.Column</a> for more details.

 *
 * <p>This class represents the xtype 'booleancolumn' and serves as a
 * typed config object for constructor of class BooleanColumn.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.BooleanColumn
 */
{ExtConfig:{target:"ext.grid.BooleanColumn", gctype:"booleancolumn"}},
"public class booleancolumn extends ext.config.gridcolumn",3,function($$private){var $1=ext.config;return[ 

  "public function booleancolumn",function booleancolumn(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.gridcolumn.call(this,config);
  },


  /**
   The string returned by the renderer when the column value is falsy (but not undefined) (defaults to <tt>'false'</tt>).
   */
  "public native function get falseText"/*():String*/,

  /**
   * @private
   */
  "public native function set falseText"/*(value:String):void*/,

  /**
   The string returned by the renderer when the column value is not falsy (defaults to <tt>'true'</tt>).
   */
  "public native function get trueText"/*():String*/,

  /**
   * @private
   */
  "public native function set trueText"/*(value:String):void*/,

  /**
   The string returned by the renderer when the column value is undefined (defaults to <tt>'&amp;#160;'</tt>).
   */
  "public native function get undefinedText"/*():String*/,

  /**
   * @private
   */
  "public native function set undefinedText"/*(value:String):void*/,


undefined];},[],["ext.config.gridcolumn"], "0.8.0", "0.9.12"
);
